# UpstreamGroupMapping

An object describing the mapping between an issuer's upstream groups and groups in the Agilicus system. The mapping is applied when the user completes a login prior to the access token being issued. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**UpstreamGroupMappingSpec**](UpstreamGroupMappingSpec.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


